@@ -229,6 +229,15 @@ ada_gtk_list_store_set_int (GtkListStore *list_store,
   gtk_list_store_set (list_store, iter, col, val, -1);
 }
 
+void
+ada_gtk_list_store_set_boolean (GtkListStore *list_store,
+                            GtkTreeIter  *iter,
+                            gint          col,
+                            gboolean          val)
+{
+  gtk_list_store_set (list_store, iter, col, val, -1);
+}
+
 void
 ada_gtk_list_store_set_pixbuf (GtkListStore *list_store,
                             GtkTreeIter  *iter,
@@ -3241,6 +3250,12 @@ ada_gslist_get_data (GSList* list)
   return list->data;
 }
 
+gpointer
+ada_slist_get_data (GSList* list)
+{
+  return list->data;
+}
+
 /******************************************
  ** Functions for Status bar
  ******************************************/
@@ -3799,13 +3814,13 @@ ada_genum_get_value (GEnumValue* value)
   return value->value;
 }
 
-gchar*
+const gchar*
 ada_genum_get_name (GEnumValue* value)
 {
   return value->value_name;
 }
 
-gchar*
+const gchar*
 ada_genum_get_nick (GEnumValue* value)
 {
   return value->value_nick;
@@ -3827,13 +3842,13 @@ ada_gflags_get_value (GFlagsValue* value)
   return value->value;
 }
 
-gchar*
+const gchar*
 ada_gflags_get_name (GFlagsValue* value)
 {
   return value->value_name;
 }
 
-gchar*
+const gchar*
 ada_gflags_get_nick (GFlagsValue* value)
 {
   return value->value_nick;
@@ -3855,6 +3870,12 @@ ada_gparam_get_flags (GParamSpec* param)
   return param->flags;
 }
 
+GType
+ada_gparam_get_owner_type (GParamSpec* param)
+{
+  return param->owner_type;
+}
+
 GType
 ada_gparam_get_value_type (GParamSpec* param)
 {
@@ -4170,6 +4191,12 @@ ada_gtype_fundamental (GType type)
   return G_TYPE_FUNDAMENTAL (type);
 }
 
+gboolean
+ada_g_type_is_interface (GType type)
+{
+  return G_TYPE_IS_INTERFACE (type);
+}
+
 /******************************************
  ** Functions for Tree_Iter
  ******************************************/
@@ -4336,6 +4363,154 @@ ada_gtk_text_buffer_insert_with_tags_by_name
 }
 
 GtkTextTag*
-ada_gtk_text_buffer_create_tag (GtkTextBuffer* buffer, const gchar* name) {
+ada_gtk_text_buffer_create_tag (GtkTextBuffer* buffer, const gchar* name)
+{
    return gtk_text_buffer_create_tag (buffer, name, NULL);
 }
+
+/***********************************************************
+ ** Gtk_File_Filter
+***********************************************************/
+
+const gchar* ada_file_filter_info_get_filename (GtkFileFilterInfo* info)
+{
+  if (info->contains & GTK_FILE_FILTER_FILENAME) {
+    return info->filename;
+  } else {
+    return NULL;
+  }
+}
+
+const gchar* ada_file_filter_info_get_uri (GtkFileFilterInfo* info)
+{
+  if (info->contains & GTK_FILE_FILTER_URI) {
+    return info->uri;
+  } else {
+    return NULL;
+  }
+}
+
+const gchar* ada_file_filter_info_get_display_name (GtkFileFilterInfo* info)
+{
+  if (info->contains & GTK_FILE_FILTER_DISPLAY_NAME) {
+    return info->display_name;
+  } else {
+    return NULL;
+  }
+}
+
+const gchar* ada_file_filter_info_get_mime_type (GtkFileFilterInfo* info)
+{
+  if (info->contains & GTK_FILE_FILTER_MIME_TYPE) {
+    return info->mime_type;
+  } else {
+    return NULL;
+  }
+}
+
+/***********************************************************
+ ** Gtk_File_Chooser_Dialog
+***********************************************************/
+
+GtkWidget *
+ada_gtk_file_chooser_dialog_new
+  (const gchar          *title,
+   GtkWindow            *parent,
+   GtkFileChooserAction  action)
+{
+  return gtk_file_chooser_dialog_new (title, parent, action, NULL);
+}
+
+GtkWidget *
+ada_gtk_file_chooser_dialog_new_with_backend
+  (const gchar          *title,
+   GtkWindow            *parent,
+   GtkFileChooserAction  action,
+   const gchar          *backend)
+{
+  return gtk_file_chooser_dialog_new_with_backend
+    (title, parent, action, backend, NULL);
+}
+
+/**************************************************************
+ **  Gtk_Message_Dialog
+**************************************************************/
+
+void
+ada_gtk_message_dialog_format_secondary_markup
+  (GtkMessageDialog* dialog, gchar* msg)
+{
+  gtk_message_dialog_format_secondary_markup (dialog, msg);
+}
+
+void
+ada_gtk_message_dialog_format_secondary_text
+  (GtkMessageDialog* dialog, gchar* msg)
+{
+  gtk_message_dialog_format_secondary_text (dialog, msg);
+}
+
+GtkWidget*
+ada_gtk_message_dialog_new
+  (GtkWindow      *parent,
+  GtkDialogFlags  flags,
+  GtkMessageType  type,
+  GtkButtonsType  buttons,
+  const gchar    *message)
+{
+  return gtk_message_dialog_new (parent, flags, type, buttons, message);
+}
+
+GtkWidget*
+ada_gtk_message_dialog_new_with_markup
+  (GtkWindow      *parent,
+  GtkDialogFlags  flags,
+  GtkMessageType  type,
+  GtkButtonsType  buttons,
+  const gchar    *message)
+{
+  return gtk_message_dialog_new_with_markup
+    (parent, flags, type, buttons, message);
+}
+
+/**************************************************************
+ **  Gtk_Bindings
+**************************************************************/
+
+void
+ada_gtk_binding_entry_add_signal_NO
+  (GtkBindingSet* set, guint keyval, GdkModifierType modifier,
+   const gchar* signal_name)
+{
+  gtk_binding_entry_add_signal (set, keyval, modifier, signal_name, 0);
+}
+
+void
+ada_gtk_binding_entry_add_signal_int
+  (GtkBindingSet* set, guint keyval, GdkModifierType modifier,
+   const gchar* signal_name, gint arg1)
+{
+  gtk_binding_entry_add_signal
+    (set, keyval, modifier, signal_name, 1,
+     G_TYPE_INT, arg1);
+}
+
+void
+ada_gtk_binding_entry_add_signal_int_int
+  (GtkBindingSet* set, guint keyval, GdkModifierType modifier,
+   const gchar* signal_name, gint arg1, gint arg2)
+{
+  gtk_binding_entry_add_signal
+    (set, keyval, modifier, signal_name, 2,
+     G_TYPE_INT, arg1, G_TYPE_INT, arg2);
+}
+
+void
+ada_gtk_binding_entry_add_signal_bool
+  (GtkBindingSet* set, guint keyval, GdkModifierType modifier,
+   const gchar* signal_name, gboolean arg1)
+{
+  gtk_binding_entry_add_signal
+    (set, keyval, modifier, signal_name, 1,
+     G_TYPE_BOOLEAN, arg1);
+}
